@@ -1,20 +1,24 @@
 runtime_init <- function(
   target = NULL,
-  frames = NULL
+  frames = NULL,
+  interactive = NULL
 ) {
   runtime_new(
     target = target,
-    frames = frames
+    frames = frames,
+    interactive = interactive
   )
 }
 
 runtime_new <- function(
   target = NULL,
-  frames = NULL
+  frames = NULL,
+  interactive = NULL
 ) {
   runtime_class$new(
     target = target,
-    frames = frames
+    frames = frames,
+    interactive = interactive
   )
 }
 
@@ -26,12 +30,15 @@ runtime_class <- R6::R6Class(
   public = list(
     target = NULL,
     frames = NULL,
+    interactive = NULL,
     initialize = function(
       target = NULL,
-      frames = NULL
+      frames = NULL,
+      interactive = NULL
     ) {
       self$target <- target
       self$frames <- frames
+      self$interactive <- interactive
     },
     exists_target = function() {
       !is.null(self$target)
@@ -39,24 +46,36 @@ runtime_class <- R6::R6Class(
     exists_frames = function() {
       !is.null(self$frames)
     },
+    exists_interactive = function() {
+      !is.null(self$interactive)
+    },
     get_target = function() {
       self$target
     },
     get_frames = function() {
       self$frames
     },
+    get_interactive = function() {
+      self$interactive
+    },
     set_target = function(target) {
       self$target <- target
     },
     set_frames = function(frames) {
       self$frames <- frames
     },
+    set_interactive = function(interactive) {
+      self$interactive <- interactive
+    },
     unset_target = function() {
       self$target <- NULL
     },
     unset_frames = function() {
       self$frames <- NULL
     },
+    unset_interactive = function() {
+      self$interactive <- NULL
+    },
     validate = function() {
       if (!is.null(self$target)) {
         tar_assert_inherits(self$target, "tar_target")
@@ -65,6 +84,10 @@ runtime_class <- R6::R6Class(
       if (!is.null(self$frames)) {
         frames_validate(self$frames)
       }
+      if (!is.null(self$interactive)) {
+        tar_assert_scalar(self$interactive)
+        tar_assert_lgl(self$interactive)
+      }
     }
   )
 )
