@@ -512,7 +512,8 @@ tar_assert_script <- function(script) {
     "Read https://books.ropensci.org/targets/practices.html#loading-and-configuring-r-packages", # nolint
     "and https://books.ropensci.org/targets/practices.html#packages-based-invalidation", # nolint
     "for the correct way to load packages for {targets} pipelines.",
-    "Suppress this warning with Sys.setenv(TAR_WARN = \"false\")."
+    "Warnings like this one are important, but if you must suppress them, ",
+    "you can do so with Sys.setenv(TAR_WARN = \"false\")."
   )
   for (loader in c("load_all", "load_code", "load_data", "load_dll")) {
     if (!identical(Sys.getenv("TAR_WARN"), "false") && loader %in% vars) {
