@@ -182,7 +182,7 @@ test_that("Same with worker-side storage", {
   }
 })
 
-test_that("future.batchtools resources", {
+test_that("future.batchtools structured resources", {
   # Needs sge_batchtools.tmpl (in current directory).
   unlink("_targets", recursive = TRUE)
   on.exit(unlink("_targets", recursive = TRUE))
@@ -193,8 +193,35 @@ test_that("future.batchtools resources", {
       future.batchtools::batchtools_sge,
       template = "sge_batchtools.tmpl"
     )
-    list(tar_target(x, Sys.sleep(10), resources = list(slots = 2)))
+    list(
+      tar_target(
+        x,
+        Sys.sleep(10),
+        resources = tar_resources(
+          future = tar_resources_future(resources = list(slots = 2))
+        )
+      )
+    )
   })
-  tar_make_future()
+  suppressWarnings(tar_make_future())
+  expect_true(tar_exist_objects("x"))
+})
+
+test_that("future.batchtools unstructured resources", {
+  # Needs sge_batchtools.tmpl (in current directory).
+  unlink("_targets", recursive = TRUE)
+  on.exit(unlink("_targets", recursive = TRUE))
+  skip_if_not_installed("future")
+  skip_if_not_installed("future.batchtools")
+  tar_script({
+    future::plan(
+      future.batchtools::batchtools_sge,
+      template = "sge_batchtools.tmpl"
+    )
+    suppressWarnings(
+      list(tar_target(x, Sys.sleep(10), resources = list(slots = 2)))
+    )
+  })
+  suppressWarnings(tar_make_future())
   expect_true(tar_exist_objects("x"))
 })
