@@ -66,6 +66,7 @@ tar_test("bad compression level throws error (unstructured resources)", {
 
 tar_test("parquet packages", {
   skip_on_cran()
+  skip_if_not_installed("arrow")
   x <- tar_target(x, 1, format = "parquet")
   out <- store_get_packages(x$store)
   expect_equal(out, "arrow")
@@ -73,6 +74,7 @@ tar_test("parquet packages", {
 
 tar_test("parquet format captures error messages", {
   skip_on_cran()
+  skip_if_not_installed("arrow")
   tar_script(tar_target(x, stop("message123"), format = "parquet"))
   expect_error(
     tar_make(callr_function = NULL),
@@ -83,6 +85,7 @@ tar_test("parquet format captures error messages", {
 
 tar_test("same with error = \"continue\"", {
   skip_on_cran()
+  skip_if_not_installed("arrow")
   tar_script(
     tar_target(x, stop("message123"), format = "parquet", error = "continue")
   )
@@ -92,20 +95,20 @@ tar_test("same with error = \"continue\"", {
 
 tar_test("parquet format cannot store non-data-frames", {
   skip_on_cran()
+  skip_if_not_installed("arrow")
   tar_script(tar_target(x, 1:2, format = "parquet"))
   expect_error(
     tar_make(callr_function = NULL),
-    class = "tar_condition_validate"
+    class = "tar_condition_run"
   )
 })
 
 tar_test("same with error = \"continue\"", {
   skip_on_cran()
+  skip_if_not_installed("arrow")
   tar_script(tar_target(x, 1:2, format = "parquet", error = "continue"))
-  expect_error(
-    tar_make(callr_function = NULL),
-    class = "tar_condition_validate"
-  )
+  tar_make(callr_function = NULL)
+  expect_true(nchar(tar_meta(x, error)$error[1]) > 5)
 })
 
 tar_test("does not inherit from tar_external", {
@@ -116,6 +119,7 @@ tar_test("does not inherit from tar_external", {
 
 tar_test("store_row_path()", {
   skip_on_cran()
+  skip_if_not_installed("arrow")
   store <- tar_target(x, "x_value", format = "parquet")$store
   store$file$path <- "path"
   expect_equal(store_row_path(store), NA_character_)
@@ -123,6 +127,7 @@ tar_test("store_row_path()", {
 
 tar_test("store_path_from_record()", {
   skip_on_cran()
+  skip_if_not_installed("arrow")
   store <- tar_target(x, "x_value", format = "parquet")$store
   record <- record_init(name = "x", path = "path", format = "parquet")
   expect_equal(
