@@ -11,7 +11,7 @@ tar_test("tar_bind() works", {
   suppressWarnings(
     expect_warning(
       tar_make(callr_function = NULL),
-      class = "condition_deprecate"
+      class = "tar_condition_deprecate"
     )
   )
   expect_equal(tar_read(a), 1L)
@@ -28,15 +28,25 @@ tar_test("tar_bind() errors if names are duplicated", {
     tar_bind(pipeline1, pipeline2)
   })
   suppressWarnings(
-    expect_error(tar_make(callr_function = NULL), class = "condition_validate")
+    expect_error(
+      tar_make(callr_function = NULL),
+      class = "tar_condition_validate"
+    )
   )
 })
 
 tar_test("valid pipeline with patterns only (#245)", {
-  expect_silent(out1 <- pipeline_init(list(tar_target(x, y, pattern = map(y)))))
-  expect_silent(out2 <- pipeline_init(list(tar_target(z, w, pattern = map(w)))))
+  expect_silent(
+    out1 <- pipeline_init(list(tar_target(x, y, pattern = map(y))))
+  )
+  expect_silent(
+    out2 <- pipeline_init(list(tar_target(z, w, pattern = map(w))))
+  )
   suppressWarnings(
-    expect_warning(out3 <- tar_bind(out1, out2), class = "condition_deprecate")
+    expect_warning(
+      out3 <- tar_bind(out1, out2),
+      class = "tar_condition_deprecate"
+    )
   )
   expect_silent(pipeline_validate(out1))
   expect_silent(pipeline_validate(out2))
